# CSRReasonEnum

A certificate Signing Request (CSR) reason status.  pending: The certificate signing is in progress failed: The certificate failed to be issued. issued: The signed certificate has been successfully issued 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


